/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Ejb.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.ant.archive;

import java.io.File;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;
import org.ow2.easybeans.ant.archive.api.IEjb;
import org.ow2.easybeans.ant.archive.exploded.EjbExploded;
import org.ow2.easybeans.ant.archive.file.EjbFile;
import org.ow2.easybeans.ant.archive.info.EjbInfo;

/**
 * Task that creates an EJB jar archive (.jar file or .jar directory).
 * @author Florent Benoit
 */
public class Ejb extends AbsArchive {

    /**
     * Reference to the persistence deployment descriptor.
     */
    private File persistenceDeploymentDescriptor = null;

    /**
     * Default constructor.
     */
    public Ejb() {
        super();
    }

    /**
     * Sets the reference to the persistence deployment descriptor.
     * @param persistenceDD the given persistence deployment descriptor.
     */
    public void setPersistenceDD(final File persistenceDD) {
        // Ignore empty value
        if ("empty-value".equals(persistenceDD.getName())) {
            return;
        }

        if (!persistenceDD.exists()) {
            throw new BuildException("The given file '" + persistenceDD + "' for the deployment descriptor does not exist.");
        }
        this.persistenceDeploymentDescriptor = persistenceDD;
    }

    /**
     * Execute the task by using either exploded or file mode.
     */
    @Override
    public void execute() {

        log("Building Ejb in '" + getDest() + "'.", Project.MSG_INFO);

        IEjb ejb = null;

        // 2 cases, exploded mode or not
        if (isExploded()) {
            ejb = new EjbExploded(getProject());
        } else {
            ejb = new EjbFile(getProject());
        }

        // Set the name of the task
        ((Task) ejb).setTaskName(getTaskName());

        // Build the info object
        EjbInfo ejbInfo = new EjbInfo();
        ejb.setEjbInfo(ejbInfo);

        // Fill archive properties
        updateArchiveInfo(ejbInfo);
        ejbInfo.setPersistenceDD(persistenceDeploymentDescriptor);

        // Execute the task
        ejb.execute();

    }

}
