/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WarExploded.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.ant.archive.exploded;

import org.apache.tools.ant.Project;
import org.ow2.easybeans.ant.archive.api.IWar;
import org.ow2.easybeans.ant.archive.info.WarInfo;

/**
 * Build a War archive in exploded mode.
 * @author Florent Benoit
 */
public class WarExploded extends AbsExplodedArchive implements IWar {

    /**
     * Path to the Standard deployment descriptor.
     */
    private static final String DEPLOYMENT_DESCRIPTOR = "WEB-INF/web.xml";

    /**
     * Path to the Specific deployment descriptor.
     */
    private static final String SPECIFIC_DEPLOYMENT_DESCRIPTOR = "WEB-INF/easybeans.xml";


    /**
     * Creates an archive for the given project.
     * @param p the given project
     */
    public WarExploded(final Project p) {
        super(p);
    }

    /**
     * Sets the information about a war archive.
     * @param warInfo the object that holds data information.
     */
    public void setWarInfo(final WarInfo warInfo) {
        setArchiveInfo(warInfo);
    }

    /**
     * Gets the path to the standard deployment descriptor.
     * @return the path to the standard deployment descriptor.
     */
    @Override
    public String getDDStandardName() {
        return DEPLOYMENT_DESCRIPTOR;
    }

    /**
     * Gets the path to the specific deployment descriptor.
     * @return the path to the specific deployment descriptor.
     */
    @Override
    public String getDDSpecificame() {
        return SPECIFIC_DEPLOYMENT_DESCRIPTOR;
    }

}
