/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBClusteredBeanEvent.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.api.event.bean;

import java.util.List;

import org.ow2.easybeans.api.binding.EZBRef;
import org.ow2.easybeans.api.event.lifecycle.EZBEventLifeCycle;
import org.ow2.util.event.api.IEventListener;

/**
 *
 * @author eyindanga.
 */
public class EZBClusteredBeanEvent implements EZBEventLifeCycle {

    /**
     * The next event number.
     */
    protected static long nextNumber = 1;

    /**
     * Container is starting.
     */
    public static String STARTING = "STARTING";

    /**
     * Container is stopping.
     */
    public static String STOPPING = "STOPPING";

    /**
     * The event number.
     */
    private long number;

    /**
     * The event time.
     */
    private long time;

    /**
     * The event source.
     */
    private String source;
    /**
     * <code>STARTING or STOPPING</code>
     */
    private String state = null;

    /**
     * Beans references.
     */
    List<EZBRef> references = null;
    /**
     * @return the state.
     */
    public String getState() {
        return this.state;
    }
    public void setState(final String state) {
        this.state = state;
    }
    /**
     * default contructor.
     */
    public EZBClusteredBeanEvent() {
        this.number = EZBClusteredBeanEvent.nextNumber++;
        this.time = System.currentTimeMillis();
    }

    public List<EZBRef> getReferences() {
        return this.references;
    }
    /**
     * Set beans references.
     * @param references
     */
    public void setReferences(final List<EZBRef> references) {
        this.references = references;
    }

    /**
     * Constructor using fields.
     * @param source source of the event.
     * @param callbackInfo some bean infos
     * @param reference Bean reference.
     */
    public EZBClusteredBeanEvent(final String source, final String state, final List<EZBRef> references) {
        this.state = state;
        this.source = source;
        this.references = references;
        this.number = EZBClusteredBeanEvent.nextNumber++;
        this.time = System.currentTimeMillis();
    }
    /**
     * Get the id of event provider.
     */
    public String getEventProviderId() {
        return this.source;
    }
    /**
     * Get events number.
     */
    public long getNumber() {
        return this.number;
    }
    /**
     * Get time.
     */
    public long getTime() {
        return this.time;
    }
    /**
     * Check permissions.
     */
    public boolean checkPermission(final IEventListener arg0) {
        return true;
    }

}
