/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EasyBeansManagedRuntime.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.persistence.openjpa;

import javax.naming.InitialContext;
import javax.transaction.TransactionManager;

import org.apache.openjpa.ee.AbstractManagedRuntime;
import org.apache.openjpa.ee.ManagedRuntime;

/**
 * This class manages the specific features required for OpenJPA : the link to
 * the Transaction manager.
 * @author Florent Benoit
 */
public class EasyBeansManagedRuntime extends AbstractManagedRuntime implements ManagedRuntime {

    /**
     * JOTM binding in registry.
     */
    private static final String JOTM_BINDING = "javax.transaction.UserTransaction";

    /**
     * @return the TransactionManager for the managed runtime. This manager is
     *         used to register synchronization listeners, to map transactional
     *         PersistenceManagers to the current transaction, and possibly to
     *         enlist XA resources.
     * @throws Exception if the transactionManager cannot be found.
     */
    public TransactionManager getTransactionManager() throws Exception {
        return (TransactionManager) new InitialContext().lookup(JOTM_BINDING);
    }

    /**
     * Returns the Throwable that caused the current transaction to be marked
     * for rollback, provided that any exists.
     * @return the Throwable cause, or null if none
     * @throws Exception if problems
     */
    public Throwable getRollbackCause() throws Exception {
        return null;
    }

    /**
     * Sets the rollback only flag on the current transaction. If the
     * TransactionManager is capable of tracking the cause of the rollback-only
     * flag, it will also pass along cause information.
     * @param cause the Throwable that caused the transaction to be marked for
     *        rollback, or null of none is known
     * @throws Exception if the transactionManager cannot be found.
     */
    public void setRollbackOnly(final Throwable cause) throws Exception {
        getTransactionManager().getTransaction().setRollbackOnly();
    }

}
